==> jc-huazhu-client-0.0.7-sources.jar: com/xforceplus/jchuazhu/controller/FlowReplayLogFeignApi.java <==
package com.xforceplus.jchuazhu.controller;


/**
 * 流程回放日志feign客户端
 *
 * @author ultraman
 * @date 2022-11-08
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.jchuazhu.entity.FlowReplayLog;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-huazhu")
public interface FlowReplayLogFeignApi {

  /**
   * 通过id查询流程回放日志
   * @param  id
   * @return R
   */
  @GetMapping("/flowReplayLog/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增流程回放日志
   * @param flowReplayLog 流程回放日志
   * @return R
   */
  @PostMapping("/flowReplayLog/add")
  public R save(@RequestBody FlowReplayLog flowReplayLog);

  /**
   * 修改流程回放日志
   * @param flowReplayLog 流程回放日志
   * @return R
   */
  @PostMapping("/flowReplayLog/update")
  public R updateById(@RequestBody FlowReplayLog flowReplayLog);

  /**
   * 通过id删除流程回放日志
   * @param  id
   * @return R
   */
  @DeleteMapping("/flowReplayLog/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> jc-huazhu-client-0.0.98-sources.jar: com/xforceplus/jchuazhu/controller/FlowReplayLogFeignApi.java <==
package com.xforceplus.jchuazhu.controller;


/**
 * 流程回放日志feign客户端
 *
 * @author ultraman
 * @date 2023-05-04
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.jchuazhu.entity.FlowReplayLog;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-huazhu")
public interface FlowReplayLogFeignApi {

  /**
   * 通过id查询流程回放日志
   * @param  id
   * @return R
   */
  @GetMapping("/flowReplayLog/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增流程回放日志
   * @param flowReplayLog 流程回放日志
   * @return R
   */
  @PostMapping("/flowReplayLog/add")
  public R save(@RequestBody FlowReplayLog flowReplayLog);

  /**
   * 修改流程回放日志
   * @param flowReplayLog 流程回放日志
   * @return R
   */
  @PostMapping("/flowReplayLog/update")
  public R updateById(@RequestBody FlowReplayLog flowReplayLog);

  /**
   * 通过id删除流程回放日志
   * @param  id
   * @return R
   */
  @DeleteMapping("/flowReplayLog/del/{id}" )
  public R removeById(@PathVariable Long id);

}
